@@ -1,3 +1,4 @@
+from warnings import warn
 from ewokscore.cliutils import add_execute_parameters as _add_execute_parameters
 from ewokscore.cliutils import apply_execute_parameters
 from ewokscore.cliutils import add_convert_parameters  # noqa F401
@@ -7,11 +8,11 @@ from ewokscore.cliutils import apply_convert_parameters  # noqa F401
 def add_execute_parameters(parser, shell=False):
     _add_execute_parameters(parser, shell=shell)
     parser.add_argument(
-        "--binding",
+        "--engine",
         type=str,
         choices=["none", "dask", "ppf", "orange"],
         default="none",
-        help="Task binding to be used",
+        help="Execution engine to be used",
     )
 
 
@@ -27,3 +28,8 @@ def add_submit_parameters(parser, shell=False):
 
 def apply_submit_parameters(args, shell=False):
     apply_execute_parameters(args, shell=shell)
+    if args.binding:
+        if args.engine:
+            raise ValueError("--binding and --engine cannot be used together")
+        args.engine = args.binding
+        warn("--binding is deprecated in favor of --engine", FutureWarning)
